==> apigateway-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnUsagePlanProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGateway::UsagePlan`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:19:33.718Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnUsagePlanProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ApiGateway::UsagePlan.ApiStages`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-apistages
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object getApiStages();
    /**
     * `AWS::ApiGateway::UsagePlan.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDescription();
    /**
     * `AWS::ApiGateway::UsagePlan.Quota`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-quota
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object getQuota();
    /**
     * `AWS::ApiGateway::UsagePlan.Throttle`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-throttle
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Object getThrottle();
    /**
     * `AWS::ApiGateway::UsagePlan.UsagePlanName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-usageplanname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getUsagePlanName();

    /**
     * @return a {@link Builder} of {@link CfnUsagePlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnUsagePlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _apiStages;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.lang.Object _quota;
        @javax.annotation.Nullable
        private java.lang.Object _throttle;
        @javax.annotation.Nullable
        private java.lang.String _usagePlanName;

        /**
         * Sets the value of ApiStages
         * @param value `AWS::ApiGateway::UsagePlan.ApiStages`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withApiStages(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._apiStages = value;
            return this;
        }
        /**
         * Sets the value of ApiStages
         * @param value `AWS::ApiGateway::UsagePlan.ApiStages`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withApiStages(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._apiStages = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::ApiGateway::UsagePlan.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Quota
         * @param value `AWS::ApiGateway::UsagePlan.Quota`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withQuota(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._quota = value;
            return this;
        }
        /**
         * Sets the value of Quota
         * @param value `AWS::ApiGateway::UsagePlan.Quota`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withQuota(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.CfnUsagePlan.QuotaSettingsProperty value) {
            this._quota = value;
            return this;
        }
        /**
         * Sets the value of Throttle
         * @param value `AWS::ApiGateway::UsagePlan.Throttle`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withThrottle(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._throttle = value;
            return this;
        }
        /**
         * Sets the value of Throttle
         * @param value `AWS::ApiGateway::UsagePlan.Throttle`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withThrottle(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.CfnUsagePlan.ThrottleSettingsProperty value) {
            this._throttle = value;
            return this;
        }
        /**
         * Sets the value of UsagePlanName
         * @param value `AWS::ApiGateway::UsagePlan.UsagePlanName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withUsagePlanName(@javax.annotation.Nullable final java.lang.String value) {
            this._usagePlanName = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUsagePlanProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnUsagePlanProps build() {
            return new CfnUsagePlanProps() {
                @javax.annotation.Nullable
                private final java.lang.Object $apiStages = _apiStages;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.lang.Object $quota = _quota;
                @javax.annotation.Nullable
                private final java.lang.Object $throttle = _throttle;
                @javax.annotation.Nullable
                private final java.lang.String $usagePlanName = _usagePlanName;

                @Override
                public java.lang.Object getApiStages() {
                    return this.$apiStages;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.Object getQuota() {
                    return this.$quota;
                }

                @Override
                public java.lang.Object getThrottle() {
                    return this.$throttle;
                }

                @Override
                public java.lang.String getUsagePlanName() {
                    return this.$usagePlanName;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getApiStages() != null) {
                        obj.set("apiStages", om.valueToTree(this.getApiStages()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getQuota() != null) {
                        obj.set("quota", om.valueToTree(this.getQuota()));
                    }
                    if (this.getThrottle() != null) {
                        obj.set("throttle", om.valueToTree(this.getThrottle()));
                    }
                    if (this.getUsagePlanName() != null) {
                        obj.set("usagePlanName", om.valueToTree(this.getUsagePlanName()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.CfnUsagePlanProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.ApiStages`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-apistages
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Object getApiStages() {
            return this.jsiiGet("apiStages", java.lang.Object.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.Quota`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-quota
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Object getQuota() {
            return this.jsiiGet("quota", java.lang.Object.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.Throttle`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-throttle
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.Object getThrottle() {
            return this.jsiiGet("throttle", java.lang.Object.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.UsagePlanName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-usageplanname
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getUsagePlanName() {
            return this.jsiiGet("usagePlanName", java.lang.String.class);
        }
    }
}

==> apigateway-1.2.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/apigateway/CfnUsagePlanProps.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * Properties for defining a `AWS::ApiGateway::UsagePlan`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-25T16:44:24.034Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnUsagePlanProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ApiGateway::UsagePlan.ApiStages`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-apistages
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getApiStages();
    /**
     * `AWS::ApiGateway::UsagePlan.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();
    /**
     * `AWS::ApiGateway::UsagePlan.Quota`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-quota
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getQuota();
    /**
     * `AWS::ApiGateway::UsagePlan.Throttle`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-throttle
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getThrottle();
    /**
     * `AWS::ApiGateway::UsagePlan.UsagePlanName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-usageplanname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getUsagePlanName();

    /**
     * @return a {@link Builder} of {@link CfnUsagePlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnUsagePlanProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _apiStages;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.lang.Object _quota;
        @javax.annotation.Nullable
        private java.lang.Object _throttle;
        @javax.annotation.Nullable
        private java.lang.String _usagePlanName;

        /**
         * Sets the value of ApiStages
         * @param value `AWS::ApiGateway::UsagePlan.ApiStages`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withApiStages(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._apiStages = value;
            return this;
        }
        /**
         * Sets the value of ApiStages
         * @param value `AWS::ApiGateway::UsagePlan.ApiStages`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withApiStages(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._apiStages = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::ApiGateway::UsagePlan.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Quota
         * @param value `AWS::ApiGateway::UsagePlan.Quota`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withQuota(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._quota = value;
            return this;
        }
        /**
         * Sets the value of Quota
         * @param value `AWS::ApiGateway::UsagePlan.Quota`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withQuota(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.CfnUsagePlan.QuotaSettingsProperty value) {
            this._quota = value;
            return this;
        }
        /**
         * Sets the value of Throttle
         * @param value `AWS::ApiGateway::UsagePlan.Throttle`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withThrottle(@javax.annotation.Nullable final software.amazon.awscdk.core.IResolvable value) {
            this._throttle = value;
            return this;
        }
        /**
         * Sets the value of Throttle
         * @param value `AWS::ApiGateway::UsagePlan.Throttle`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withThrottle(@javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.CfnUsagePlan.ThrottleSettingsProperty value) {
            this._throttle = value;
            return this;
        }
        /**
         * Sets the value of UsagePlanName
         * @param value `AWS::ApiGateway::UsagePlan.UsagePlanName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withUsagePlanName(@javax.annotation.Nullable final java.lang.String value) {
            this._usagePlanName = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnUsagePlanProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnUsagePlanProps build() {
            return new CfnUsagePlanProps() {
                @javax.annotation.Nullable
                private final java.lang.Object $apiStages = _apiStages;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.lang.Object $quota = _quota;
                @javax.annotation.Nullable
                private final java.lang.Object $throttle = _throttle;
                @javax.annotation.Nullable
                private final java.lang.String $usagePlanName = _usagePlanName;

                @Override
                public java.lang.Object getApiStages() {
                    return this.$apiStages;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.lang.Object getQuota() {
                    return this.$quota;
                }

                @Override
                public java.lang.Object getThrottle() {
                    return this.$throttle;
                }

                @Override
                public java.lang.String getUsagePlanName() {
                    return this.$usagePlanName;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    if (this.getApiStages() != null) {
                        obj.set("apiStages", om.valueToTree(this.getApiStages()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getQuota() != null) {
                        obj.set("quota", om.valueToTree(this.getQuota()));
                    }
                    if (this.getThrottle() != null) {
                        obj.set("throttle", om.valueToTree(this.getThrottle()));
                    }
                    if (this.getUsagePlanName() != null) {
                        obj.set("usagePlanName", om.valueToTree(this.getUsagePlanName()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.apigateway.CfnUsagePlanProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.ApiStages`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-apistages
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Object getApiStages() {
            return this.jsiiGet("apiStages", java.lang.Object.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.Quota`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-quota
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Object getQuota() {
            return this.jsiiGet("quota", java.lang.Object.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.Throttle`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-throttle
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.Object getThrottle() {
            return this.jsiiGet("throttle", java.lang.Object.class);
        }

        /**
         * `AWS::ApiGateway::UsagePlan.UsagePlanName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html#cfn-apigateway-usageplan-usageplanname
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getUsagePlanName() {
            return this.jsiiGet("usagePlanName", java.lang.String.class);
        }
    }
}
